@@ -1,5 +1,9 @@
-__version__ = '0.2.6'
+__version__ = '0.3.0'
 
 from .idseqs_to_mask import idseqs_to_mask
 from .dense_sparse_matmul import dense_sparse_matmul
 from .get_sparsity_pattern import get_sparsity_pattern
+from .sparsity_analysis import (
+    shortest_path_to_origin,
+    feedback_signal_patterns
+)
\ No newline at end of file
